Rename GrContentKey to GrUniqueKey

Review URL: https://codereview.chromium.org/940463006
diff --git a/src/gpu/GrGpuResourceCacheAccess.h b/src/gpu/GrGpuResourceCacheAccess.h
index 52294ce..df0ca34 100644
--- a/src/gpu/GrGpuResourceCacheAccess.h
+++ b/src/gpu/GrGpuResourceCacheAccess.h
@@ -23,10 +23,10 @@
 private:
     /**
      * Is the resource currently cached as scratch? This means it is cached, has a valid scratch
      * key, and does not have a content key.
      */
     bool isScratch() const {
-        return !fResource->getContentKey().isValid() && fResource->fScratchKey.isValid() &&
+        return !fResource->getUniqueKey().isValid() && fResource->fScratchKey.isValid() &&
                 fResource->resourcePriv().isBudgeted();
     }
@@ -23,10 +23,10 @@
     /**
      * Is the resource currently cached as scratch? This means it is cached, has a valid scratch
-     * key, and does not have a content key.
+     * key, and does not have a unique key.
      */
     bool isScratch() const {